function [power,frequency] = specan_power(obj,frequency,file)
%SPECAN_POWER Leistungsmessung
%   Kommunikation erfolgt mit SCPI-Befehlen
%   input arguments
%       obj             Instrument Object
%       frequency       Messfrequenzen
%       file            Dateiname
%   output arguments
%       power           Leistungen in Watt
%       frequency       Messfrequenzen
%
%   Zum Bestimmen der Leistungsdichten msste man die Leistungen auf die
%   Rauschbandbreite, das heit 1.064*rbw normieren.
%
%   Instrument Control Toolbox 
%       S. 1-23 bis 1-24
%       S. 3-19 bis 3-24
%
%   SCPI-Befehle 
%       CALCulate<1|2>:MARKer<1...4>:FUNCtion:SUMMary:RMS[:STATe] ON | OFF
%       [SENSe<1|2>:]FREQuency:CENTer 0 .. fmax
%       INITiate<1|2>[:IMMediate]
%       *WAI
%       CALCulate<1|2>:MARKer<1...4>:FUNCtion:SUMMary:RMS:RESult?
%       TRACe<n>[:DATA]? <ResultType>
%
%   05.09.2019          T. Weber    
%   13.12.2020          Untersttzung fr FPC1500 und FPL1003 hinzugefgt

switch obj.Name
    case 'none'
        % Messwerte aus Datei lesen
        data = load(file,'-ascii');
        frequency = data(:,1);
        power = data(:,2);
        
    case {'zvl','fpl'}  
        % Speicher allokieren
        power = zeros(numel(frequency),1);
        
         % Leistungsmessung einschalten
        fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS ON');
       
        for m = 1:numel(frequency)
            
            % Messfrequenz einstellen
            fprintf(obj,'FREQ:CENT %f',frequency(m));
            
            % tatschliche Messfrequenz auslesen
            fprintf(obj,'FREQ:CENT?');
            frequency(m) = fscanf(obj,'%f');

            % Sweep ausfhren
            fprintf(obj,'INIT');
            fprintf(obj,'*WAI');

            % Leistung auslesen
            fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS:RES?');
            power(m) = 10^(fscanf(obj,'%f')/10)*1e-3; % dBm in Watt umrechnen

            % Sweep ausfhren
            fprintf(obj,'INIT');
            fprintf(obj,'*WAI');

            % Leistung auslesen
            fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS:RES?');
            power(m) = 10^(fscanf(obj,'%f')/10)*1e-3; % dBm in Watt umrechnen

        end
        
        % Leistungsmessung ausschalten
        fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS OFF');

        % Messwerte in Datei schreiben
        data = [frequency(:),power];
        save(file,'data','-ascii');

    case 'fsq' 
        % Speicher allokieren
        power = zeros(numel(frequency),1);
        
         % Leistungsmessung einschalten
        fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS ON');
       
        for m = 1:numel(frequency)
            
            % Messfrequenz einstellen
            fprintf(obj,'FREQ:CENT %f',frequency(m));
            
            % tatschliche Messfrequenz auslesen
            fprintf(obj,'FREQ:CENT?');
            frequency(m) = fscanf(obj,'%f');

            % die erste Messung ist unbrauchbar
            fprintf(obj,'INIT');
            fprintf(obj,'*WAI');
            fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS:RES?');
            power(m) = 10^(fscanf(obj,'%f')/10)*1e-3; % dBm in Watt umrechnen

            % Sweep ausfhren
            fprintf(obj,'INIT');
            fprintf(obj,'*WAI');

            % Leistung auslesen
            fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS:RES?');
            power(m) = 10^(fscanf(obj,'%f')/10)*1e-3; % dBm in Watt umrechnen

        end
        
        % Leistungsmessung ausschalten
        fprintf(obj,'CALC:MARK:FUNC:SUMM:RMS OFF');

        % Messwerte in Datei schreiben
        data = [frequency(:),power];
        save(file,'data','-ascii');

    case 'fpc'  
        % Speicher allokieren
        power = zeros(numel(frequency),1);
        
        for m = 1:numel(frequency)
            
            % Messfrequenz einstellen
            fprintf(obj,'FREQ:CENT %f',frequency(m));
            
            % tatschliche Messfrequenz auslesen
            fprintf(obj,'FREQ:CENT?');
            frequency(m) = fscanf(obj,'%f');

            % Sweep ausfhren
            fprintf(obj,'INIT');
            fprintf(obj,'*WAI');

            % Trace auslesen, kommaseparierte Liste mit scanstr parsen
            fprintf(obj,'TRAC?');
            raw_data = textscan(fscanf(obj),'%f','Delimiter',',','TreatAsEmpty','-1.#INF','EmptyValue',-Inf);
            power(m) = mean(10.^(raw_data{1}/10)*1e-3);

        end
        
        % Messwerte in Datei schreiben
        data = [frequency(:),power];
        save(file,'data','-ascii');

    otherwise
    	error('unsupported spectrum analyzer');
        
end

end
